@@ -7,7 +7,6 @@ The tested code might be in _page.py.
 import re
 from dataclasses import asdict
 from io import BytesIO
-from pathlib import Path
 from unittest.mock import patch
 
 import pytest
@@ -19,12 +18,7 @@ from pypdf._text_extraction._layout_mode._fixed_width_page import text_show_oper
 from pypdf.errors import PdfReadError
 from pypdf.generic import ContentStream
 
-from . import get_data_from_url
-
-TESTS_ROOT = Path(__file__).parent.resolve()
-PROJECT_ROOT = TESTS_ROOT.parent
-RESOURCE_ROOT = PROJECT_ROOT / "resources"
-SAMPLE_ROOT = PROJECT_ROOT / "sample-files"
+from . import RESOURCE_ROOT, SAMPLE_ROOT, get_data_from_url
 
 
 @pytest.mark.samples
@@ -149,9 +143,8 @@ def test_font_class_to_dict():
                 1000.0,
                 900.0,
             ),
-            "character_widths": {"default": 500},
         },
-        "character_widths": {},
+        "character_widths": {"default": 500},
         "space_width": 8,
         "interpretable": True,
     }
@@ -493,3 +486,14 @@ def test_slow_huge_string():
     page = reader.pages[0]
 
     _ = page.extract_text(extraction_mode="layout")
+
+
+@pytest.mark.enable_socket
+def test_extract_text_with_missing_font_bbox():
+    url = "https://github.com/user-attachments/files/24611650/bbox_bug_emoji.pdf"
+    name = "issue-3599.pdf"
+    stream = BytesIO(get_data_from_url(url, name=name))
+    reader = PdfReader(stream)
+    page = reader.pages[0]
+    text = page.extract_text()
+    assert "🎉" in text
